ClausiusClapeyron class

Clausius-Clapeyron relation for vapor pressure variation with temperature.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pressureRatio({required double enthalpyJmol, required double temperatureK, required double temperatureDeltaK}) double
vaporPressure({required double referencePressure, required double enthalpyJmol, required double referenceTemperatureK, required double temperatureK}) double