FickFirstLaw class

Fick's first law for steady-state diffusion.

The model implements the flux relation [ J = -D \nabla C ] where D is the diffusion coefficient in m^2/s and grad(C) is the concentration gradient in mol/m^4 (or equivalent concentration per length).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

diffusionCoefficient({required double flux, required double concentrationGradient}) double
Calculates the diffusion coefficient from flux and gradient.
flux({required double diffusionCoefficient, required double concentrationGradient}) double
Calculates diffusive flux from a diffusion coefficient and concentration gradient.